#+
#   ARES/HADES/BORG Package -- python/aquila_borg/utils.py
#   Copyright (C) 2014-2025 The Aquila-Consortium developers <aquila-consortium@services.cnrs.fr>
#   Authors:

#
#   Contributions from:
#      Guilhem Lavaux <guilhem.lavaux@iap.fr> (2021, 2023-2024)
#
#+

"""
Utility functions
-----------------

General utility functions for borg data management.

"""

import numpy as np
from .borg_native import *


def newComplexOutputSlab(fwd_model: forward.BORGForwardModel):
    """Helper function to create an empty numpy of the correct shape for the given forward model

    Args:
      * fwd_model: A BORGForwardModel

    Returns:
       numpy.ndarray: An allocated numpy array with MPI slicing
    """
    startN0, localN0, N1, N2 = fwd_model.getMPISlice()
    return np.empty((localN0, N1, N2 // 2 + 1), dtype=np.complex128)


def newRealOutputSlab(fwd_model: forward.BORGForwardModel):
    """Helper function to create an empty numpy of the correct shape for the given forward model

    Args:
      * fwd_model: A BORGForwardModel

    Returns:
       numpy.ndarray: An allocated numpy array with MPI slicing
    """
    startN0, localN0, N1, N2 = fwd_model.getMPISlice()
    return np.empty((localN0, N1, N2))
